using UnityEngine; // 41 Post - Created by DimasTheDriver on Dec/21/2011 . Part of the 'Unity: How to playback fullscreen videos using the GL class' post. Available at: http://www.41post.com/?p=4570
using System.Collections;

[RequireComponent (typeof (AudioSource))]

public class PlayVideo : MonoBehaviour 
{
	//a Material where the movie texture will be displayed
	public Material mat;
	//the name of the movie file (without the extension)
	public string movieName;
	//the texture wich holds the movie
	private MovieTexture mTex;
	//an AudioSource to play the audio from the movie
	private AudioSource movieAS;
	
	//Use this for early initialization
	void Awake() 
	{
		//if the material hasn't been found
		if (!mat) 
		{
			Debug.LogError("Please assign a material on the Inspector.");
			return;
		}
		
		//load the movie texture from the 'Resources' folder
		mTex = (MovieTexture)Resources.Load(movieName);
		
		//get the atttached AudioSource component
		movieAS = this.GetComponent<AudioSource>();
		
		//set the AudioSource clip to be the same as the movie texture audio clip
		movieAS.clip = mTex.audioClip;
	}
	
	//Use this for initialization
	void Start()
	{
		//assign the video texture to the material texture
		mat.SetTexture("_MainTex", mTex);
		
		//Play the video
		mTex.Play();
		
		//Play the audio from the movie
		movieAS.Play(); 
	}
	
	void Update()
	{
		//Check if the video has finished playing
		if(!mTex.isPlaying)
		{
			//hide the video by disabling the script
			this.enabled = false;
		}
	}
	
	//Called after camera has finished rendering the scene
	void OnPostRender()
	{
		//push current matrix into the matrix stack
		GL.PushMatrix();
		//set the material pass
		mat.SetPass(0);
		//load orthogonal projection matrix
		GL.LoadOrtho();
		//render a quad where the video will be displayed
		GL.Begin(GL.QUADS);
			//set the color
			GL.Color(Color.white);
			//Define the quad texture coordinates and vertices
			GL.TexCoord2(0, 0);
			GL.Vertex3(0.0f, 0.0f, 0);
			GL.TexCoord2(0, 1);
			GL.Vertex3(0.0f, 1.0f, 0);
			GL.TexCoord2(1, 1);
			GL.Vertex3(1.0f, 1.0f, 0);
			GL.TexCoord2(1, 0);
			GL.Vertex3(1.0f, 0.0f, 0);
		GL.End();
		//pop the orthogonal matrix from the stack
		GL.PopMatrix();
	}
}
