// 41 Post - Created by DimasTheDriver on Dec/21/2011 . Part of the 'Unity: How to playback fullscreen videos using the GL class' post. Available at: http://www.41post.com/?p=4570
@script RequireComponent(AudioSource)
//a Material where the movie texture will be displayed
public var mat:Material;
//a Material for the black stripes
public var blackMat:Material;
//the name of the movie file (without the extension)
public var movieName:String;
//the texture wich holds the movie
private var mTex:MovieTexture;
//an AudioSource to play the audio from the movie
private var movieAS:AudioSource;

//the quad height needed to be display the video in the letterbox format
private var quadHeight:float;
//Y position of the bottom vertices
private var quadBottomVert:float;
	
//Use this for early initialization
function Awake() 
{
	//if the material hasn't been found
	if (!mat) 
	{
		Debug.LogError("Please assign a material on the Inspector.");
		return;
	}
	
	//load the movie texture from the 'Resources' folder
	mTex = Resources.Load(movieName);
	
	//get the atttached AudioSource component
	movieAS = this.GetComponent(AudioSource);
	
	//set the AudioSource clip to be the same as the movie texture audio clip
	movieAS.clip = mTex.audioClip;
	
	//find out the quad height based on the screen width and the inverse of the movie aspect ratio
	quadHeight =  (mTex.height/parseFloat(mTex.width)) * Screen.width;
	//find the Y position of the bottom vertices
	quadBottomVert = (Screen.height - quadHeight)/2;
}

//Use this for initialization
function Start()
{
	//assign the video texture to the material texture
	mat.SetTexture("_MainTex", mTex);
	
	//Play the video
	mTex.Play();
	
	//Play the audio from the movie
	movieAS.Play(); 
}

function Update()
{
	//Check if the video has finished playing
	if(!mTex.isPlaying)
	{
		//hide the video by disabling the script
		this.enabled = false;
	}
}

//Called after camera has finished rendering the scene
function OnPostRender()
{
	//push current matrix into Che matrix stack
	GL.PushMatrix();
	//set the material pass
	blackMat.SetPass(0);
	//load orthogonal pixel projection matrix
	GL.LoadPixelMatrix();
	//render a black quad that takes the whole screen
	GL.Begin(GL.QUADS);
		//set the color
		GL.Color(Color.white);
		//Define the quad vertices
		GL.Vertex3(0.0f, 0.0f, -1.0f);
		GL.Vertex3(0.0f, Screen.height+1, -1.0f);
		GL.Vertex3(Screen.width, Screen.height+1, -1.0f);
		GL.Vertex3(Screen.width, 0.0f, -1.0f);
	GL.End();
	//set the material pass
	mat.SetPass(0);
	//render a quad where the video will be displayed
	GL.Begin(GL.QUADS);
		//set the color
		GL.Color(Color.white);
		//Define the quad texture coordinates and vertices
		GL.TexCoord2(0, 0);
		GL.Vertex3(0.0f, quadBottomVert, 0);
		GL.TexCoord2(0, 1);
		GL.Vertex3(0.0f, quadBottomVert + quadHeight, 0);
		GL.TexCoord2(1, 1);
		GL.Vertex3(Screen.width, quadBottomVert + quadHeight, 0);
		GL.TexCoord2(1, 0);
		GL.Vertex3(Screen.width, quadBottomVert, 0);
	GL.End();
	//pop the orthogonal matrix from the stack
	GL.PopMatrix();
}